@@ -1,14 +1,19 @@
+# this is the code for FileGPT.py
 #!/usr/bin/env python
 
 import sys
 import os
-import openai
 import logging
 import tempfile
 
+from openai_wrapper import get_openai_response
+from personalities import PERSONALITIES, get_personality, get_openai_personality
+
 import tiktoken
 from typing import List
 
+PERSONALITY = None
+
 MODELS = [
     "gpt-3.5-turbo",
     "gpt-4"
@@ -35,7 +40,9 @@ def read_input(files: List[str] = None) -> str:
         content = "\n".join(contents)
     else:
         logging.info("Reading input from stdin")
-        print("Reading from stdin (press CTRL+D for linux/mac or Enter+CTRL+Z+Enter for windows to stop)...")
+        if os.isatty(sys.stdin.fileno()):
+            print("Current personality:", get_personality(PERSONALITY))
+            print("Reading from stdin (press CTRL+D for linux/mac or Enter+CTRL+Z+Enter for windows to stop)...")
         content = sys.stdin.read()
     return content
 
@@ -55,19 +62,6 @@ def select_model(model_name:str) -> str:
 
     return model_name
 
-def get_openai_response(model_name:str, content:str):
-    logging.info("Setting up OpenAI API")
-    openai.api_key = os.getenv("OPENAI_API_KEY")
-    message = {"role": "user", "content": content}
-    
-    logging.info("Sending request to OpenAI API")
-    response = openai.ChatCompletion.create(
-        model=model_name,
-        messages=[message],
-        stream=True
-    )
-    return response
-
 def write_output(response):
     logging.info("Writing output")
     response_str = ""
@@ -90,7 +84,8 @@ def process_text(model_name: str, input_files: List[str] = None) -> str:
 
     logging.info("Input has %d tokens", len(enc.encode(input_content)))
 
-    response = get_openai_response(model_name, input_content)
+    print(get_openai_personality(PERSONALITY))
+    response = get_openai_response(model_name, [get_openai_personality(PERSONALITY), {"role": "user", "content": input_content}])
     resp_str = write_output(response)
     logging.info("FileGPT finished, response has %d tokens", len(enc.encode(resp_str)))
     
@@ -101,13 +96,25 @@ def main():
     parser = argparse.ArgumentParser(description="FileGPT - A simple tool that autocompletes text files.")
     parser.add_argument("-f", "--file", help="Specify one or more text files as input.", type=str, nargs="+")
     parser.add_argument("-m", "--model", help="Specify the model to use for autocompletion.", type=str)
+    parser.add_argument("-p", "--personality", help="Specify the personality to use for autocompletion.", type=str)
+
+    parser.add_argument("personalities", help="Perform operations on available personalities.", type=str, nargs="?", choices=["p-ls"])
     args = parser.parse_args()
+
+    if args.personalities:
+        # handle personalities argument
+        if args.personalities == "p-ls":
+            # list available personalities
+            print(f"Available personalities: {', '.join(PERSONALITIES)}")
+            return
     
+    global PERSONALITY
+    PERSONALITY = get_personality(args.personality)
     process_text(args.model, args.file)
 
 
 if __name__ == "__main__":
     main()
 
-# (run FileGPT on itself and ask it the question below, using `python FileGPT.py -f FileGPT.py`)
-# refactor this package such that it can be used as a library
\ No newline at end of file
+# (run FileGPT on itself and ask it the question below, using `filegpt -f FileGPT.py`)
+# How can this code be improved?
\ No newline at end of file
